@@ -71,7 +71,9 @@ class Environment(BaseModel):
         "remote-ssh",
         "uv",
         "pixi",
+        "venv",
         "uv-venv",
+        "renv",
     ]
     path: str | None = None
     description: str | None = None
@@ -79,11 +81,21 @@ class Environment(BaseModel):
     default: bool | None = None
 
 
+class VenvEnvironment(Environment):
+    kind: Literal["venv"]
+    prefix: str
+
+
 class UvVenvEnvironment(Environment):
     kind: Literal["uv-venv"]
     prefix: str
 
 
+class PixiEnvironment(Environment):
+    kind: Literal["pixi"]
+    name: str | None = None
+
+
 class DockerEnvironment(Environment):
     kind: Literal["docker"]
     image: str
@@ -92,6 +104,11 @@ class DockerEnvironment(Environment):
     platform: str | None = None
 
 
+class REnvironment(Environment):
+    kind: Literal["renv"]
+    prefix: str
+
+
 class Software(BaseModel):
     title: str
     path: str
@@ -216,7 +233,8 @@ class ProjectInfo(BaseModel):
     publications: list[Publication] = []
     references: list[ReferenceCollection] = []
     environments: dict[
-        str, Environment | DockerEnvironment | UvVenvEnvironment
+        str,
+        Environment | DockerEnvironment | VenvEnvironment | UvVenvEnvironment,
     ] = {}
     software: list[Software] = []
     notebooks: list[Notebook] = []
